
module.exports = stage;

stage.usage = "\nfhc stage app=<appId> type=<type> ",
  + "\nwhere <type> is one of: 'development' or 'release'";

var log = require("./utils/log");
var fhc = require("../fhc");
var fhreq = require("./utils/request");
var common = require("./common");
var util = require('util');
var async = require('async');

function stage (args, cb) {
  try{
    var argObj = parseArgs(args);
    validateArgs(argObj);
  } catch (x) {
    return cb("Error processing args: " + x + "\nUsage: " + stage.usage);
  }
  doStage(argObj, cb);
};

function parseArgs(args) {
  var opts = new Object();
  for(var i=0; i<args.length; i++) {
    var arg = args[i];
    if(arg.indexOf('=') == -1) throw new Error('Invalid argument format: ' + arg);
    var kv = arg.split("=");
    log.silly(kv, 'stage arg');
    opts[kv[0]] = (kv[1] == undefined ? "" : kv[1]);
  }
  return opts;
}

// runs through the args we got and validates as per our stagerules
function validateArgs(args) {
  if (args.app == undefined) throw new Error("Missing 'app' parameter");
  if (args.type == undefined) args.type = 'release';  
}

// TODO - unused
function argsToPayload(args) {
  var pl = "generateSrc=false";
  for (var i in args) {
    pl = pl + "&" + i + "=" + args[i];
  }
  return pl;
}

function waitFor(key, cb) {
  common.waitForJob(key, 0, cb);
}

function doStage(args, cb) {
  var type = 'releasestage';
  if (args.type === 'development') type = 'stage';
  var uri = "box/srv/1.1/ide/" + fhc.domain + "/app/" + type;
  var payload = {payload:{guid: args.app}};

  common.doApiCall(fhreq.getFeedHenryUrl(), uri, payload, "Error staging app: ", function(err, data) {
    async.map([data.cacheKey], waitFor, function(err, results) {
      return cb(err, results);
    });
  });
};

